@@ -8,7 +8,7 @@ import cPickle
 
 from pycache.cacheItem import CacheItem
 
-def cached(CacheItemPool='memory'):
+def cached(CacheItemPool='memory', enable=True):
     """
       Caches the result of the computation
       based on the function parameters
@@ -18,6 +18,11 @@ def cached(CacheItemPool='memory'):
     """
     def decorator(func):
         def inner(*args, **kwargs):
+            # Cache Closed
+            if enable != True:
+                return func(*args, **kwargs)
+
+            # Cache Opened
             key = (func.__name__, cPickle.dumps(args), cPickle.dumps(kwargs))
             item = CacheItemPool.get_item(key)
             if item.is_hit():
